Evaluation
======================
This module implements functions used for evaluating the value and fairness of policies.

.. code:: python

   from pycfrl import evaluation

.. automodule:: pycfrl.evaluation
   :members:
   :show-inheritance:
   :special-members: __init__